@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2005 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 
   NOTE: May, 2010. Extracted this code from
         kdepim/incidenceeditors/editorattachments.{h,cpp}
@@ -41,11 +25,10 @@
 #include <QKeyEvent>
 #include <QMimeData>
 #include <QMimeDatabase>
-#include <QMimeType>
 
 using namespace IncidenceEditorNG;
 
-AttachmentIconItem::AttachmentIconItem(const KCalCore::Attachment &att, QListWidget *parent)
+AttachmentIconItem::AttachmentIconItem(const KCalendarCore::Attachment &att, QListWidget *parent)
     : QListWidgetItem(parent)
 {
     if (!att.isEmpty()) {
@@ -53,10 +36,10 @@ AttachmentIconItem::AttachmentIconItem(const KCalCore::Attachment &att, QListWid
     } else {
         // for the enterprise, inline attachments are the default
 #ifdef KDEPIM_ENTERPRISE_BUILD
-        mAttachment = KCalCore::Attachment(QByteArray()); // use the non-uri constructor
+        mAttachment = KCalendarCore::Attachment(QByteArray()); // use the non-uri constructor
         // as we want inline by default
 #else
-        mAttachment = KCalCore::Attachment(QString());
+        mAttachment = KCalendarCore::Attachment(QString());
 #endif
     }
     readAttachment();
@@ -67,7 +50,7 @@ AttachmentIconItem::~AttachmentIconItem()
 {
 }
 
-KCalCore::Attachment AttachmentIconItem::attachment() const
+KCalendarCore::Attachment AttachmentIconItem::attachment() const
 {
     return mAttachment;
 }
@@ -134,7 +117,7 @@ QPixmap AttachmentIconItem::icon() const
 
 QPixmap AttachmentIconItem::icon(const QMimeType &mimeType, const QString &uri, bool binary)
 {
-    QString iconStr = mimeType.iconName();
+    const QString iconStr = mimeType.iconName();
     QStringList overlays;
     if (!uri.isEmpty() && !binary) {
         overlays << QStringLiteral("emblem-link");
@@ -150,7 +133,7 @@ void AttachmentIconItem::readAttachment()
 
     QMimeDatabase db;
     if (mAttachment.mimeType().isEmpty()
-        || !(db.mimeTypeForName(mAttachment.mimeType()).isDefault())) {
+        || !(db.mimeTypeForName(mAttachment.mimeType()).isValid())) {
         QMimeType mimeType;
         if (mAttachment.isUri()) {
             mimeType = db.mimeTypeForUrl(QUrl(mAttachment.uri()));
@@ -217,7 +200,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
     QStringList labels;
     for (QListWidgetItem *it : items) {
         if (it->isSelected()) {
-            AttachmentIconItem *item = static_cast<AttachmentIconItem *>(it);
+            auto *item = static_cast<AttachmentIconItem *>(it);
             if (item->isBinary()) {
                 urls.append(item->tempFileForAttachment());
             } else {
@@ -227,7 +210,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
         }
     }
     if (selectionMode() == NoSelection) {
-        AttachmentIconItem *item = static_cast<AttachmentIconItem *>(currentItem());
+        auto *item = static_cast<AttachmentIconItem *>(currentItem());
         if (item) {
             urls.append(QUrl(item->uri()));
             labels.append(QString::fromLatin1(QUrl::toPercentEncoding(item->label())));
@@ -237,7 +220,7 @@ QMimeData *AttachmentIconView::mimeData(const QList< QListWidgetItem *> items) c
     QMap<QString, QString> metadata;
     metadata[QStringLiteral("labels")] = labels.join(QLatin1Char(':'));
 
-    QMimeData *mimeData = new QMimeData;
+    auto *mimeData = new QMimeData;
     mimeData->setUrls(urls);
     KUrlMimeData::setMetaData(metadata, mimeData);
     return mimeData;
@@ -263,7 +246,7 @@ void AttachmentIconView::startDrag(Qt::DropActions supportedActions)
 
     const QPoint hotspot(pixmap.width() / 2, pixmap.height() / 2);
 
-    QDrag *drag = new QDrag(this);
+    auto *drag = new QDrag(this);
     drag->setMimeData(mimeData());
 
     drag->setPixmap(pixmap);
