@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2000, 2001, 2002 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2002 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "categoryselectdialog.h"
@@ -49,7 +36,7 @@ CategorySelectWidget::CategorySelectWidget(CategoryConfig *cc, QWidget *parent)
     : QWidget(parent)
     , mCategoryConfig(cc)
 {
-    QHBoxLayout *topL = new QHBoxLayout(this);
+    auto *topL = new QHBoxLayout(this);
     topL->setContentsMargins(0, 0, 0, 0);
     mWidgets = new CategorySelectWidgetBase(this);
     topL->addWidget(mWidgets);
@@ -167,7 +154,7 @@ CategorySelectDialog::CategorySelectDialog(CategoryConfig *cc, QWidget *parent)
     , d(nullptr)
 {
     setWindowTitle(i18nc("@title:window", "Select Categories"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
         QDialogButtonBox::Ok | QDialogButtonBox::Cancel /*| QDialogButtonBox::Help*/ | QDialogButtonBox::Apply,
         this);
@@ -177,7 +164,7 @@ CategorySelectDialog::CategorySelectDialog(CategoryConfig *cc, QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &CategorySelectDialog::reject);
 
     QWidget *page = new QWidget;
-    QVBoxLayout *lay = new QVBoxLayout(page);
+    auto *lay = new QVBoxLayout(page);
     lay->setContentsMargins(0, 0, 0, 0);
 
     mWidgets = new CategorySelectWidget(cc, this);
