@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2009 Sebastian Sauer <sebsauer@kdab.net>
+  SPDX-FileCopyrightText: 2009 Sebastian Sauer <sebsauer@kdab.net>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef INCIDENCEEDITOR_EDITORCONFIG_H
@@ -25,7 +9,7 @@
 
 #include "incidenceeditor_export.h"
 
-#include <KCalCore/IncidenceBase>
+#include <KCalendarCore/IncidenceBase>
 
 #include <QUrl>
 
@@ -114,7 +98,7 @@ public:
         return QStringList();
     }
 
-    Q_REQUIRED_RESULT virtual QStringList &templates(KCalCore::IncidenceBase::IncidenceType type);
+    Q_REQUIRED_RESULT virtual QStringList &templates(KCalendarCore::IncidenceBase::IncidenceType type);
 
 private:
     class Private;
