@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "editoritemmanager.h"
@@ -74,8 +61,6 @@ public:
 
 ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorItemManager *qq)
     : q_ptr(qq)
-    , mItemMonitor(nullptr)
-    , mIsCounterProposal(false)
     , currentAction(EditorItemManager::None)
 {
     mFetchScope.fetchFullPayload();
@@ -89,18 +74,14 @@ ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorI
                                                                 qq), qq);
 
     qq->connect(mChanger,
-                SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,
-                                      QString)),
+                SIGNAL(modifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
                 qq,
-                SLOT(onModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,
-                                      QString)));
+                SLOT(onModifyFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
 
     qq->connect(mChanger,
-                SIGNAL(createFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,
-                                      QString)),
+                SIGNAL(createFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)),
                 qq,
-                SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,
-                                      QString)));
+                SLOT(onCreateFinished(int,Akonadi::Item,Akonadi::IncidenceChanger::ResultCode,QString)));
 }
 
 void ItemEditorPrivate::moveJobFinished(KJob *job)
@@ -130,7 +111,7 @@ void ItemEditorPrivate::itemFetchResult(KJob *job)
         return;
     }
 
-    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     if (fetchJob->items().isEmpty()) {
         mItemUi->reject(ItemEditorUi::ItemFetchFailed);
         return;
@@ -163,7 +144,7 @@ void ItemEditorPrivate::itemMoveResult(KJob *job)
     Q_Q(EditorItemManager);
 
     if (job->error()) {
-        Akonadi::ItemMoveJob *moveJob = qobject_cast<Akonadi::ItemMoveJob *>(job);
+        auto *moveJob = qobject_cast<Akonadi::ItemMoveJob *>(job);
         Q_ASSERT(moveJob);
         Q_UNUSED(moveJob);
         //Q_ASSERT(!moveJob->items().isEmpty());
@@ -246,7 +227,7 @@ void ItemEditorPrivate::itemChanged(const Akonadi::Item &item, const QSet<QByteA
         dlg->addButton(i18n("Ignore and Overwrite changes"), QMessageBox::RejectRole);
 
         if (dlg->exec() == QMessageBox::AcceptRole) {
-            Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(mItem);
+            auto *job = new Akonadi::ItemFetchJob(mItem);
             job->setFetchScope(mFetchScope);
 
             mItem = item;
@@ -313,7 +294,7 @@ void EditorItemManager::load(const Akonadi::Item &item)
     Q_D(ItemEditor);
 
     //We fetch anyways to make sure we have everything required including tags
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     job->setFetchScope(d->mFetchScope);
     connect(job, SIGNAL(result(KJob*)), SLOT(itemFetchResult(KJob*)));
 }
