@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencedatetime.h"
@@ -899,20 +886,65 @@ bool IncidenceDateTime::endDateTimeEnabled() const
     return mUi->mEndCheck->isChecked();
 }
 
+
+void IncidenceDateTime::focusInvalidField()
+{
+    if (startDateTimeEnabled()) {
+        if (!mUi->mStartDateEdit->isValid()) {
+            mUi->mStartDateEdit->setFocus();
+            return;
+        }
+        if (!mUi->mWholeDayCheck->isChecked() && !mUi->mStartTimeEdit->isValid()) {
+            mUi->mStartTimeEdit->setFocus();
+            return;
+        }
+    }
+    if (endDateTimeEnabled()) {
+        if (!mUi->mEndDateEdit->isValid()) {
+            mUi->mEndDateEdit->setFocus();
+            return;
+        }
+        if (!mUi->mWholeDayCheck->isChecked() && !mUi->mEndTimeEdit->isValid()) {
+            mUi->mEndTimeEdit->setFocus();
+            return;
+        }
+    }
+    if (startDateTimeEnabled() && endDateTimeEnabled()
+        && currentStartDateTime() > currentEndDateTime()) {
+        if (mUi->mEndDateEdit->date() < mUi->mStartDateEdit->date()) {
+            mUi->mEndDateEdit->setFocus();
+        } else {
+            mUi->mEndTimeEdit->setFocus();
+        }
+    }
+}
+
 bool IncidenceDateTime::isValid() const
 {
-    if (startDateTimeEnabled() && !currentStartDateTime().isValid()) {
-        mLastErrorString = i18nc("@info",
-                                 "Invalid start date and time.");
-        qCWarning(INCIDENCEEDITOR_LOG) << "Start date is invalid";
-        return false;
+    if (startDateTimeEnabled()) {
+        if (!mUi->mStartDateEdit->isValid()) {
+            mLastErrorString = i18nc("@info", "Invalid start date.");
+            qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
+            return false;
+        }
+        if (!mUi->mWholeDayCheck->isChecked() && !mUi->mStartTimeEdit->isValid()) {
+            mLastErrorString = i18nc("@info", "Invalid start time.");
+            qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
+            return false;
+        }
     }
 
-    if (endDateTimeEnabled() && !currentEndDateTime().isValid()) {
-        mLastErrorString = i18nc("@info",
-                                 "Invalid end date and time.");
-        qCWarning(INCIDENCEEDITOR_LOG) << "End date is invalid";
-        return false;
+    if (endDateTimeEnabled()) {
+        if (!mUi->mEndDateEdit->isValid()) {
+            mLastErrorString = i18nc("@info", "Invalid end date.");
+            qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
+            return false;
+        }
+        if (!mUi->mWholeDayCheck->isChecked() && !mUi->mEndTimeEdit->isValid()) {
+            mLastErrorString = i18nc("@info", "Invalid end time.");
+            qCDebug(INCIDENCEEDITOR_LOG) << mLastErrorString;
+            return false;
+        }
     }
 
     if (startDateTimeEnabled() && endDateTimeEnabled()
