@@ -1,22 +1,9 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-  Copyright (C) 2012  Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2012 Allen Winter <winter@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencedialog.h"
@@ -90,7 +77,7 @@ public:
     IncidenceResource *mIeResource = nullptr;
     bool mInitiallyDirty = false;
     Akonadi::Item mItem;
-    QString typeToString(const int type) const;
+    Q_REQUIRED_RESULT QString typeToString(const int type) const;
 
 public:
     IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq);
@@ -130,15 +117,13 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
     : q_ptr(qq)
     , mUi(new Ui::EventOrTodoDesktop)
     , mCalSelector(new Akonadi::CollectionComboBox(changer ? changer->entityTreeModel() : nullptr))
-    , mCloseOnSave(false)
     , mItemManager(new EditorItemManager(this, changer))
     , mEditor(new CombinedIncidenceEditor(qq))
-    , mInitiallyDirty(false)
 {
     Q_Q(IncidenceDialog);
     mUi->setupUi(q);
     mUi->mMessageWidget->hide();
-    QGridLayout *layout = new QGridLayout(mUi->mCalSelectorPlaceHolder);
+    auto *layout = new QGridLayout(mUi->mCalSelectorPlaceHolder);
     layout->setSpacing(0);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mCalSelector);
@@ -149,31 +134,31 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
 
     // Now instantiate the logic of the dialog. These editors update the ui, validate
     // fields and load/store incidences in the ui.
-    IncidenceWhatWhere *ieGeneral = new IncidenceWhatWhere(mUi);
+    auto *ieGeneral = new IncidenceWhatWhere(mUi);
     mEditor->combine(ieGeneral);
 
-    IncidenceCategories *ieCategories = new IncidenceCategories(mUi);
+    auto *ieCategories = new IncidenceCategories(mUi);
     mEditor->combine(ieCategories);
 
     mIeDateTime = new IncidenceDateTime(mUi);
     mEditor->combine(mIeDateTime);
 
-    IncidenceCompletionPriority *ieCompletionPriority = new IncidenceCompletionPriority(mUi);
+    auto *ieCompletionPriority = new IncidenceCompletionPriority(mUi);
     mEditor->combine(ieCompletionPriority);
 
-    IncidenceDescription *ieDescription = new IncidenceDescription(mUi);
+    auto *ieDescription = new IncidenceDescription(mUi);
     mEditor->combine(ieDescription);
 
-    IncidenceAlarm *ieAlarm = new IncidenceAlarm(mIeDateTime, mUi);
+    auto *ieAlarm = new IncidenceAlarm(mIeDateTime, mUi);
     mEditor->combine(ieAlarm);
 
-    IncidenceAttachment *ieAttachments = new IncidenceAttachment(mUi);
+    auto *ieAttachments = new IncidenceAttachment(mUi);
     mEditor->combine(ieAttachments);
 
     mIeRecurrence = new IncidenceRecurrence(mIeDateTime, mUi);
     mEditor->combine(mIeRecurrence);
 
-    IncidenceSecrecy *ieSecrecy = new IncidenceSecrecy(mUi);
+    auto *ieSecrecy = new IncidenceSecrecy(mUi);
     mEditor->combine(ieSecrecy);
 
     mIeAttendee = new IncidenceAttendee(qq, mIeDateTime, mUi);
@@ -638,10 +623,8 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
         mCalSelector->setDefaultCollection(Akonadi::Collection(item.storageCollectionId()));
     }
 
-    if (!mCalSelector->mimeTypeFilter().contains(QLatin1String("text/calendar"))
-        || !mCalSelector->mimeTypeFilter().contains(incidence->mimeType())) {
-        mCalSelector->setMimeTypeFilter(QStringList() << incidence->mimeType()
-                                                      << QStringLiteral("text/calendar"));
+    if (!mCalSelector->mimeTypeFilter().contains(incidence->mimeType())) {
+        mCalSelector->setMimeTypeFilter({incidence->mimeType()});
     }
 
     if (mEditor->type() == KCalendarCore::Incidence::TypeTodo) {
