@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "incidenceresource.h"
@@ -32,7 +16,6 @@
 #include <KDescendantsProxyModel>
 #include <KEmailAddress>
 
-#include <QCompleter>
 
 using namespace IncidenceEditorNG;
 
@@ -76,11 +59,11 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     attrs << QStringLiteral("cn") <<  QStringLiteral("mail");
 
     completer = new QCompleter(this);
-    ResourceModel *model = new ResourceModel(attrs, this);
+    auto *model = new ResourceModel(attrs, this);
 
-    KDescendantsProxyModel *proxyModel = new KDescendantsProxyModel(this);
+    auto *proxyModel = new KDescendantsProxyModel(this);
     proxyModel->setSourceModel(model);
-    SwitchRoleProxy *proxyModel2 = new SwitchRoleProxy(this);
+    auto *proxyModel2 = new SwitchRoleProxy(this);
     proxyModel2->setSourceModel(proxyModel);
 
     completer->setModel(proxyModel2);
@@ -88,9 +71,9 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
     completer->setWrapAround(false);
     mUi->mNewResource->setCompleter(completer);
 
-    AttendeeLineEditDelegate *attendeeDelegate = new AttendeeLineEditDelegate(this);
+    auto *attendeeDelegate = new AttendeeLineEditDelegate(this);
 
-    ResourceFilterProxyModel *filterProxyModel = new ResourceFilterProxyModel(this);
+    auto *filterProxyModel = new ResourceFilterProxyModel(this);
     filterProxyModel->setDynamicSortFilter(true);
     filterProxyModel->setSourceModel(dataModel);
 
@@ -120,6 +103,11 @@ IncidenceResource::IncidenceResource(IncidenceAttendee *ieAttendee, IncidenceDat
             &IncidenceResource::updateCount);
 }
 
+IncidenceResource::~IncidenceResource()
+{
+    delete resourceDialog;
+}
+
 void IncidenceResource::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     Q_UNUSED(incidence);
