@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "individualmaildialog.h"
@@ -25,9 +9,7 @@
 #include <KGuiItem>
 #include <KLocalizedString>
 
-#include <QDialogButtonBox>
 #include <QGridLayout>
-#include <QComboBox>
 #include <QLabel>
 #include <QPushButton>
 
@@ -38,11 +20,11 @@ IndividualMailDialog::IndividualMailDialog(const QString &question, const KCalen
 {
     setWindowTitle(i18nc("@title:window", "Group Scheduling Email"));
     m_detailsWidget = new QWidget();
-    QGridLayout *layout = new QGridLayout(m_detailsWidget);
+    auto *layout = new QGridLayout(m_detailsWidget);
     mAttendeeDecision.reserve(attendees.size());
     int row = 0;
     for (const KCalendarCore::Attendee &attendee : attendees) {
-        QComboBox *options = new QComboBox();
+        auto *options = new QComboBox();
         options->addItem(i18nc("@item:inlistbox ITIP Messages for one attendee",
                                "Send update"), QVariant(Update));
         options->addItem(i18nc("@item:inlistbox ITIP Messages for one attendee",
