@@ -1,21 +1,8 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "schedulingdialog.h"
@@ -39,7 +26,7 @@ SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTim
     , mPeriodModel(new CalendarSupport::FreePeriodModel(this))
 {
     setWindowTitle(i18nc("@title:window", "Scheduling"));
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QWidget *w = new QWidget(this);
     setupUi(w);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(
@@ -58,7 +45,7 @@ SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTim
     mDuration = duration;
 
     mVisualWidget = new VisualFreeBusyWidget(resolver->model(), 8);
-    QVBoxLayout *ganttlayout = new QVBoxLayout(mGanttTab);
+    auto *ganttlayout = new QVBoxLayout(mGanttTab);
 
     mGanttTab->setLayout(ganttlayout);
     ganttlayout->addWidget(mVisualWidget);
